@@ -1,40 +1,63 @@
+import sys
+
 import pytest
 
 from npe2._command_registry import CommandHandler, CommandRegistry
 from npe2._plugin_manager import PluginManager
+from npe2.manifest.schema import PluginManifest
+from npe2.types import PythonName
+
+SAMPLE_PLUGIN_NAME = "my-plugin"
 
 
-def test_plugin_manager(sample_path):
+@pytest.fixture
+def pm(sample_path):
+
     pm = PluginManager()
     pm.discover()
     assert len(pm._manifests) == 0
-    pm.discover([sample_path])
-    assert len(pm._manifests) == 1
-    assert pm.get_command("my_plugin.hello_world")
+    sys.path.append(str(sample_path))
+    try:
+        pm.discover()
+        yield pm
+    finally:
+        sys.path.remove(str(sample_path))
 
-    assert "my_plugin" not in pm._contexts
-    ctx = pm.activate("my_plugin")
-    assert "my_plugin" in pm._contexts
+
+def test_plugin_manager(pm: PluginManager):
+    assert pm.get_command(f"{SAMPLE_PLUGIN_NAME}.hello_world")
+
+    assert SAMPLE_PLUGIN_NAME not in pm._contexts
+    ctx = pm.activate(SAMPLE_PLUGIN_NAME)
+    assert SAMPLE_PLUGIN_NAME in pm._contexts
+    assert pm.get_manifest(SAMPLE_PLUGIN_NAME)
 
     # dual activation is prevented
-    assert pm.activate("my_plugin") is ctx
+    assert pm.activate(SAMPLE_PLUGIN_NAME) is ctx
 
-    with pytest.raises(KeyError):
-        pm.activate("not a thing")
-
-    assert pm.get_command("my_plugin.hello_world")
-    with pytest.raises(KeyError):
-        pm.get_command("my_plugin.not_a_thing")
+    assert pm.get_command(f"{SAMPLE_PLUGIN_NAME}.hello_world")
 
     assert pm.get_submenu("mysubmenu")
     assert len(list(pm.iter_menu("/napari/layer_context"))) == 2
 
     # deactivation
-    assert "my_plugin" in pm._contexts
-    pm.deactivate("my_plugin")
-    assert "my_plugin" not in pm._contexts
-    pm.deactivate("my_plugin")  # second time is a no-op
-    assert "my_plugin" not in pm._contexts
+    assert SAMPLE_PLUGIN_NAME in pm._contexts
+    pm.deactivate(SAMPLE_PLUGIN_NAME)
+    assert SAMPLE_PLUGIN_NAME not in pm._contexts
+    pm.deactivate(SAMPLE_PLUGIN_NAME)  # second time is a no-op
+    assert SAMPLE_PLUGIN_NAME not in pm._contexts
+
+
+def test_plugin_manager_raises(pm: PluginManager):
+    with pytest.raises(KeyError):
+        pm.get_manifest("not-a-pluginxxx")
+    with pytest.raises(KeyError):
+        pm.activate("not a thing")
+    with pytest.raises(KeyError):
+        pm.get_command(f"{SAMPLE_PLUGIN_NAME}.not_a_thing")
+    with pytest.raises(ValueError) as e:
+        pm.register(PluginManifest(name=SAMPLE_PLUGIN_NAME))
+    assert f"A manifest with name {SAMPLE_PLUGIN_NAME!r} already" in str(e.value)
 
 
 def test_command_handler():
@@ -44,7 +67,7 @@ def test_command_handler():
 
     with pytest.raises(RuntimeError):
         # cannot resolve something without either a python_name or function
-        CommandHandler("hi", python_name="cannot.import.this").resolve()
+        CommandHandler("hi", python_name=PythonName("cannot.import.this")).resolve()
 
 
 def test_command_reg_register():
@@ -65,6 +88,10 @@ def test_command_reg_register():
         # already registered
         reg.register("some.id", "this.is.a_valid_python_name")
 
+    with pytest.raises(KeyError) as e:
+        reg.get("not.a.command")
+    assert "command 'not.a.command' not registered" in str(e.value)
+
 
 def test_command_reg_get():
     def f(x, y):
